@@ -55,7 +55,6 @@ OOF.addItem(oofmenu.OOFMenuItem(
     cli_only=1,
     help='Create, modify, and delete material properties.',
     discussion="""<para>
-
     The <command>Property</command> menu contains the basic tools for
     managing material &properties;.  Unnamed versions of all
     &properties; are created when &oof2; starts.  The <link
@@ -67,12 +66,19 @@ OOF.addItem(oofmenu.OOFMenuItem(
     the <link
     linkend='MenuItem-OOF.Property.Delete'><command>Delete</command></link>
     command removes named &properties;.
-
-    </para>"""
+    </para>""",
+    xrefs=["Section-Tasks-Materials"]
     ))
 
 OOF.LoadData.addItem(oofmenu.OOFMenuItem(
-    'Property'
+    'Property',
+    discussion="""<para>
+
+    This is a version of the <xref linkend="MenuItem-OOF.Property"/>
+    that is used within data files. It is not used directly by the &oof2;
+    user interface.
+    
+    </para>"""
     ))
 
 #=-=##=-=##=-=##=-=##=-=##=-=##=-=##=-=##=-=##=-=##=-=##=-=##=-=##=-=##=-=#
@@ -580,13 +586,11 @@ class PropertyRegistration(PropertyRegistrationParent):
     def interfaceCompatibility(self):
         return self._interfaceCompatibility
 
-    # "Call" method creates a property instance from a registration.
-    # This is the only way to create a property instance, and this
-    # routine does not do any book-keeping with the AllProperties
-    # object.  We do not use the Registration class's __call__ method,
-    # because we need to pass the registration itself as an argument to
-    # the property constructor.
-    def __call__(self):
+    # "createProperty" creates a property instance from a
+    # registration.  This is the only way to create a property
+    # instance, and this routine does not do any book-keeping with the
+    # AllProperties object.
+    def createProperty(self):
         return self.subclass(self, self._name, *[p.value for p in self.params])
 
 
@@ -628,7 +632,7 @@ class PropertyRegistration(PropertyRegistrationParent):
                     pass
         # "m" is a MaterialProps object, "o" is the old property instance.
         for (m, o) in list(self.materials.values()):
-            newcopy = self() # Run the registration to get the prop.
+            newcopy = self.createProperty() 
             m.new_params(o, newcopy)
             self.materials[m.name]=(m, newcopy)
             switchboard.notify("material changed", m.name)
@@ -733,7 +737,7 @@ class NamedPropertyRegistration(PropertyRegistration):
     # We do not expect NamedPropertyRegistrations to be used
     # for anything other than direct instantiation via the pre-set
     # params, so no kwargs for this one.  2nd argument is name.
-    def __call__(self):
+    def createProperty(self):
         return self.subclass(self, self._name, 
                              *[p.value for p in self.params[1:]])
 
@@ -804,17 +808,28 @@ parameters for this &property;.
 
     # No discussion section for intermediate nodes in the Property
     # tree, except for the root.
-    if reg.path() == 'OOF.Property.Parametrize':
+    if menuitem.path() == 'OOF.Property.Parametrize':
         return """<para>
         The <command>Parametrize</command> menu contains an entry for
         each <emphasis>unnamed</emphasis> &property;.  The menu
         hierarchy echoes the hierarchical arrangement of the
         &properties; themselves.  Each command sets the parameters of
         a &property;.  The <emphasis>named</emphasis> &properties;
-        appear in the menus as submenus for their unnamed
-        counterparts.  They aren't listed in the documentation,
-        though.  </para>"""
-    return ""
+        appear in the menus as submenu items for their unnamed
+        counterparts.  For example,
+        <literallayout class="monospaced">
+    OOF.Property.Parametrize.Color(color=TranslucentGray(value=0.425,alpha=1))
+    OOF.Property.Parametrize.Color.<emphasis role="bold">blue</emphasis>(color=RGBAColor(red=0,green=0,blue=1,alpha=1))</literallayout>
+        sets the unnamed Color &property; to gray and a named Color
+        &property; to blue.  The menu items for named &properties;
+        aren't listed explicitly in the manual.
+        </para>
+        <para>
+        The physics and the meanings of the parameters for each
+        &property; are explained in <xref
+        linkend="Section-Properties"/>.
+        </para>"""
+    return xmlmenudump.emptyDiscussion
 
 def _parametrizeHelp(menuitem):
     reg = menuitem.data
@@ -827,42 +842,41 @@ def _parametrizeHelp(menuitem):
                    % ('n'*(name[0] in 'aeiouAEOIU'), name)
     splitpath = menuitem.path().split('.')
     proppath = splitpath[3:]            # remove "OOF.Property.Parametrize"
-    return "Set parameters for %s Properties" % stringjoin(proppath, '.')
+    return "Set parameters for %s Properties." % stringjoin(proppath, '.')
     
 
 def _loadDiscussion(menuitem):
     reg = menuitem.data
     if reg:
         name = reg.name()
-        return  """
-<para>
-Create an instance of the material &property;
-<classname>%s</classname>.  This command is only used in data files.
-Data files containing &properties; are created by the <link
-linkend='MenuItem-OOF.File.Save.Materials'><command>Materials</command></link>,
-<link
-linkend='MenuItem-OOF.File.Save.Microstructure'><command>Microstructure</command></link>,
-<link
-linkend='MenuItem-OOF.File.Save.Skeleton'><command>Skeleton</command></link>
-and <link
-linkend='MenuItem-OOF.File.Save.Mesh'><command>Mesh</command></link>
-commands in the <xref linkend='MenuItem-OOF.File.Save'/> menu.
-</para> <para> The <varname>name</varname> argument should be set to
-the name of a named &property; or to an empty string
-(<userinput>''</userinput>) when setting parameters in an unnamed
-&property;.
-</para>
-<para>
-See <xref linkend="Property-%s"/> for a complete description of the
-parameters for this &property;.
-</para>
-                """ % (reg.name(), reg.name().replace(':','-'))
+        return  f"""
+        <para>
 
-        return intro + xmlmenudump.getDiscussion(reg)
+        Create an instance of the material &property;
+        <classname>{name}</classname>.  This command is only used in
+        data files, and is not invoked by the &oof2; user interface.
+        Data files containing &properties; are created by the <link
+        linkend='MenuItem-OOF.File.Save.Materials'><command>Materials</command></link>,
+        <link
+        linkend='MenuItem-OOF.File.Save.Microstructure'><command>Microstructure</command></link>,
+        <link
+        linkend='MenuItem-OOF.File.Save.Skeleton'><command>Skeleton</command></link>
+        and <link
+        linkend='MenuItem-OOF.File.Save.Mesh'><command>Mesh</command></link>
+        commands in the <xref linkend='MenuItem-OOF.File.Save'/> menu.
+        </para>
+
+        <para> The <varname>name</varname> argument should be set to
+        the name of a named &property; or to an empty string
+        (<userinput>''</userinput>) when setting parameters in an
+        unnamed &property;.  </para> <para> See <xref
+        linkend="Property-{name.replace(':', '-')}"/> for a complete
+        description of the parameters for this &property;.
+        </para>"""
 
     # No discussion section for intermediate nodes in the Property
     # tree, except for the root.
-    if reg.path() == 'OOF.LoadData.Property':
+    if menuitem.path() == 'OOF.LoadData.Property':
         return """<para>
 
         The <command>OOF.LoadData.Property</command> menu contains an
@@ -878,21 +892,21 @@ parameters for this &property;.
         string (<userinput>''</userinput>) when assigning parameters
         to unnamed &properties;.</para>"""
 
-    return ""
+    return xmlmenudump.emptyDiscussion
 
     
 def _loadHelp(menuitem):
     reg = menuitem.data
     if reg:
         try:
-            return reg.tip + " Used internally in data files."
+            return reg.tip 
         except:
             name = reg.name()
-            return "Define a%s %s Property.  Used internally in data files." \
+            return "Define a%s %s Property." \
                    % ('n'*(name[0] in 'aeiouAEIOU'), name)
     splitpath = menuitem.path().split('.')
     proppath = splitpath[3:]            # remove "OOF.LoadDataProperty"
-    return "Set parameters for %s Properties.  This menu is used only in data files." % stringjoin(proppath, '.')
+    return "Set parameters for %s Properties." % stringjoin(proppath, '.')
     
 
 def xmldocs(phile):
@@ -1015,6 +1029,16 @@ requires and which &fluxes; and/or &equations; it contributes to.
         except AttributeError:
             print("<para>MISSING PROPERTY DISCUSSION: %s</para>" % name, file=phile)
         print('</refsect1> <!-- Discussion -->', file=phile)
+
+        ## TODO: Tie this in to the xrefs mechanism used for other
+        ## manual pages?
+        print('<refsect1>', file=phile)
+        print('  <title>See Also</title>', file=phile)
+        print('  <simpara>', file=phile)
+        print('    <xref linkend="Section-Concepts-Property"/>', file=phile)
+        print('  </simpara>', file=phile)
+        print('</refsect1>', file=phile)
+
         print('</refentry>', file=phile)
 
     print("</section> <!-- Properties -->", file=phile)
