@@ -24,39 +24,9 @@ import weakref
 class SkeletonNode(skeletonselectable.SkeletonSelectable,
                    cskeleton.CSkeletonNode):
 
-    if config.dimension() == 2:
-        def __init__(self, x, y, index):
-            skeletonselectable.SkeletonSelectable.__init__(self, index)
-            cskeleton.CSkeletonNode.__init__(self, x, y)
-            self.dimIndependentInit(index)
-
-    elif config.dimension() == 3:
-        def __init__(self, x, y, z, points, index):
-            skeletonselectable.SkeletonSelectable.__init__(self, index)
-            cskeleton.CSkeletonNode.__init__(self, x, y, z, points, index)
-            self.dimIndependentInit(index)
-
-        def moveTo(self, point):
-            # TODO 3D: this could be cleaned up if the elements were stored in C
-            # See note in cskeleton.C
-            cskeleton.CSkeletonNode.moveTo(self, point)
-            for element in self._elements:
-                element.updateVtkCellPoints()
-
-        def unconstrainedMoveTo(self, point):
-            # TODO 3D: this could be cleaned up if the elements were stored in C
-            # See note in cskeleton.C
-            cskeleton.CSkeletonNode.unconstrainedMoveTo(self, point)
-            for element in self._elements:
-                element.updateVtkCellPoints()
-
-        def moveBy(self, delta):
-            cskeleton.CSkeletonNode.moveBy(self, delta)
-            for element in self._elements:
-                element.updateVtkCellPoints()
-             
-
-    def dimIndependentInit(self, index):
+    def __init__(self, x, y, index):
+        skeletonselectable.SkeletonSelectable.__init__(self, index)
+        cskeleton.CSkeletonNode.__init__(self, x, y)
         self._elements = []
         self.ID = object_id.ObjectID()
         
@@ -65,11 +35,11 @@ class SkeletonNode(skeletonselectable.SkeletonSelectable,
             self._owners = []  # only for the initial Skeleton
             self._shared_with = []  # except me
             self._remote_index = {}  # procID : remote index
-        
+
     def __repr__(self):
-##        p = self.position()
-##        return "SkeletonNode#%d(%f, %f)" % (self.index, p.x, p.y)
-        return "SkeletonNode(%d)" % self.index
+        p = self.position()
+        return f"SkeletonNode({p.x}, {p.y}, [{self.index}])"
+        # return f"SkeletonNode({self.index})"
 
     def repr_position(self):
         return self.position()
@@ -193,7 +163,7 @@ class SkeletonNode(skeletonselectable.SkeletonSelectable,
     # DeputyPinnedNodeTracker instead of a PinnedNodeTracker.
 
     def pin(self, clist, plist):
-        self.setPinned(1)
+        self.setPinned(True)
         here = self.position()
         self.pinDown(clist, here)
         self.pinUp(plist, here)
@@ -209,7 +179,7 @@ class SkeletonNode(skeletonselectable.SkeletonSelectable,
                 plist[0].pinUp(self, plist[1:], here)
             
     def unpin(self, clist, plist):
-        self.setPinned(0)
+        self.setPinned(False)
         here = self.position()
         self.unpinDown(clist, here)
         self.unpinUp(plist, here)
@@ -329,17 +299,14 @@ class PeriodicSkeletonNode(SkeletonNode):
     def aperiodicNeighborNodes(self, skeleton):
         return SkeletonNode.neighborNodes(self, skeleton)
  
-    # the function being overridden is in the skeletonselectable class
+    # The function being overridden is in the skeletonselectable class
     def makeSibling(self, newcomer):
         SkeletonNode.makeSibling(self, newcomer)
         partners = self.getPartnerPair(newcomer)
         if partners is not None:
             SkeletonNode.makeSibling(partners[0], partners[1])
 
-
-    # TODO 3D: Will need to make this work in 3D
-
-    # given two nodes (self & node), getPartnerPair returns their
+    # Given two nodes (self & node), getPartnerPair returns their
     # partners with the same periodicity.  That is, if self has a
     # partner in the +x direction and node has partners in both +x and
     # -y, then the +x partners of both are returned.
@@ -349,9 +316,10 @@ class PeriodicSkeletonNode(SkeletonNode):
         partner2 = None
         # This node can only be a partner of another node if the other
         # node is different, but has the same x or y position, or both.
-        if self == node or node.getPartners() == [] or \
-           (self.position().x != node.position().x and
-            self.position().y != node.position().y):
+        if (self == node or
+            not node.getPartners() or
+            (self.position().x != node.position().x and
+             self.position().y != node.position().y)):
             return None
         if len(self.getPartners()) == 1:
             partner1 = self.getPartners()[0]
@@ -367,7 +335,7 @@ class PeriodicSkeletonNode(SkeletonNode):
         else:
             return partner1, partner2
         
-    # helper function for getPartnerPair used in cases where self
+    # Helper function for getPartnerPair used in cases where self
     # has more than one partner (corner node)
     def getCorrectPartner(self, node):
         if self.position().x == node.position().x:
@@ -383,7 +351,9 @@ class PeriodicSkeletonNode(SkeletonNode):
                     return p
             
     def __repr__(self):
-        return "PeriodicSkeletonNode(%d)" % self.index
+        # p = self.position()
+        # return f"PeriodicSkeletonNode({p.x}, {p.y}, [{self.index}])"
+        return f"PeriodicSkeletonNode({self.index})"
 
     def getDirectedPartner(self, direction):
         if direction == 'x':
@@ -403,121 +373,99 @@ class PeriodicSkeletonNode(SkeletonNode):
     
 #######################################################
 
-if config.dimension()==2:
+class HashedNodes:
+    def __init__(self, size, skelsize):
+        self.size = size
+        n = size[0]*size[1]
+        self.scale = (1.0*self.size[0]/skelsize[0],
+                      1.0*self.size[1]/skelsize[1])
+        self.data = [[] for i in range(n)]
+        self.outofthebox = []
 
-    class HashedNodes:
-        def __init__(self, size, skelsize):
-            self.size = size
-##            if config.dimension() == 2:
-            n = size[0]*size[1]
-            self.scale = (1.0*self.size[0]/skelsize[0],
-                          1.0*self.size[1]/skelsize[1])
-##             elif config.dimension() == 3:
-##                 n = size[0]*size[1]*size[2]
-##                 self.scale = (1.0*self.size[0]/skelsize[0],
-##                               1.0*self.size[1]/skelsize[1],
-##                               1.0*self.size[2]/skelsize[2])
-            self.data = [[] for i in range(n)]
-            self.outofthebox = []
+    def getSize(self):
+        return self.size
 
-        def getSize(self):
-            return self.size
+    def getScale(self):
+        return self.scale
 
-        def getScale(self):
-            return self.scale
+    def properTile(self, point):
+        ix = int( point.x*self.scale[0] )
+        iy = int( point.y*self.scale[1] )
+        # When right or top skeleton edge was clicked ....
+        if ix==self.size[0]: ix -= 1
+        if iy==self.size[1]: iy -= 1
+        return primitives.iPoint(ix, iy)
 
-        def properTile(self, point):
-            ix = int( point.x*self.scale[0] )
-            iy = int( point.y*self.scale[1] )
-            # When right or top skeleton edge was clicked ....
-            if ix==self.size[0]: ix -= 1
-            if iy==self.size[1]: iy -= 1
-##            if config.dimension() == 2:
-            return primitives.iPoint(ix, iy)
-##             elif config.dimension() == 3:
-##                 iz = int( point.z*self.scale[2] )
-##                 if iz==self.size[2]: iz -= 1
-##                 return primitives.iPoint(ix, iy, iz)
+    def iterator(self):
+        return self.data
 
-        def iterator(self):
-            return self.data
+    def __setitem__(self, where, val):
+        self.data[self.size[0]*where.y + where.x] = val
 
-        def __setitem__(self, where, val):
-##            if config.dimension() == 2:
-            self.data[self.size[0]*where.y + where.x] = val
-##             elif config.dimension() == 3:
-##                 self.data[self.size[1]*self.size[0]*where.z + self.size[0]*where.y + where.x] = val
+    def __getitem__(self, where):
+        try:
+            return self.data[self.size[0]*where.y + where.x]
+        except IndexError:
+            return self.outofthebox
 
-        def __getitem__(self, where):
-            try:
-##                if config.dimension()==2 and (where.x>=0 and where.y>=0):
-                return self.data[self.size[0]*where.y + where.x]
-##                 elif config.dimension()==3 and (where.x>=0 and where.y>=0 and where.z>=0):
-##                     return self.data[self.size[1]*self.size[0]*where.z +
-##                                      self.size[0]*where.y + where.x]
-##             else:
-##                 return self.outofthebox
-            except IndexError:
-                return self.outofthebox
-            
-        def hash(self, skeleton):
-            # Putting nodes in corresponding tiles
-            for node in skeleton.nodes:
-                where = self.properTile(node.position())
-                self[where].append(node)
+    def hash(self, skeleton):
+        # Putting nodes in corresponding tiles
+        for node in skeleton.nodes:
+            where = self.properTile(node.position())
+            self[where].append(node)
 
-        def nearestNode(self, point):
-            where = self.properTile(point)
+    def nearestNode(self, point):
+        where = self.properTile(point)
 
-            count = 0  # No. of tile-bands containing nodes
-            iter = 1   # No. of tile-bands having been looked at
-            nodes = self[where][:]
-            while count < 2:   
-                # Initial check
-                if iter==1:
-                    if nodes: count += 1
-                # Additional band of tiles
-                addition = self.nextBand(
-                    ll=primitives.iPoint(where.x-iter, where.y-iter),
-                    ur=primitives.iPoint(where.x+iter, where.y+iter))
-                if addition:
-                    nodes += addition
-                    count += 1
-                else:
-                    if count==1:
-                        break  # No need to look for another band
-                # Ready for the next round
-                iter += 1
+        count = 0  # No. of tile-bands containing nodes
+        iter = 1   # No. of tile-bands having been looked at
+        nodes = self[where][:]
+        while count < 2:   
+            # Initial check
+            if iter==1:
+                if nodes: count += 1
+            # Additional band of tiles
+            addition = self.nextBand(
+                ll=primitives.iPoint(where.x-iter, where.y-iter),
+                ur=primitives.iPoint(where.x+iter, where.y+iter))
+            if addition:
+                nodes += addition
+                count += 1
+            else:
+                if count==1:
+                    break  # No need to look for another band
+            # Ready for the next round
+            iter += 1
 
-            # Find the nearest node among collected nodes
-            nearest = nodes[0]
-            mindist = (nearest.position() - point)**2
-            for node in nodes[1:]:
-                dd = (node.position() - point)**2
-                if dd < mindist:
-                    mindist = dd
-                    nearest = node
-            return nearest
+        # Find the nearest node among collected nodes
+        nearest = nodes[0]
+        mindist = (nearest.position() - point)**2
+        for node in nodes[1:]:
+            dd = (node.position() - point)**2
+            if dd < mindist:
+                mindist = dd
+                nearest = node
+        return nearest
 
-        def nextBand(self, ll=None, ur=None):
-            nodes = []
-            # Bottom
-            j = ll.y
-            for i in range(ll.x, ur.x+1):
-                nodes += self[primitives.iPoint(i,j)][:]
-            # Top
-            j = ur.y
-            for i in range(ll.x, ur.x+1):
-                nodes += self[primitives.iPoint(i,j)][:]
-            # Left
-            i = ll.x
-            for j in range(ll.y+1, ur.y):
-                nodes += self[primitives.iPoint(i,j)][:]
-            # Right
-            i = ur.x
-            for j in range(ll.y+1, ur.y):
-                nodes += self[primitives.iPoint(i,j)][:]
-            return nodes
+    def nextBand(self, ll=None, ur=None):
+        nodes = []
+        # Bottom
+        j = ll.y
+        for i in range(ll.x, ur.x+1):
+            nodes += self[primitives.iPoint(i,j)][:]
+        # Top
+        j = ur.y
+        for i in range(ll.x, ur.x+1):
+            nodes += self[primitives.iPoint(i,j)][:]
+        # Left
+        i = ll.x
+        for j in range(ll.y+1, ur.y):
+            nodes += self[primitives.iPoint(i,j)][:]
+        # Right
+        i = ur.x
+        for j in range(ll.y+1, ur.y):
+            nodes += self[primitives.iPoint(i,j)][:]
+        return nodes
 
 ###############################################################
     
@@ -532,7 +480,7 @@ class PinnedNodeSet(skeletonselectable.SelectionSetBase):
     def clearskeletons(self):
         for tracker in self.selected.values():
             for n in tracker.data:
-                n.setPinned(0)
+                n.setPinned(False)
 
     def implied_select(self, oldskel, newskel):
         # Called from SelectionBase.whoChanged0() when a new
@@ -576,16 +524,16 @@ class PinnedNodeTracker(skeletonselectable.SelectionTrackerBase):
         
     def clear(self):
         for n in self.data:
-            n.setPinned(0)
+            n.setPinned(False)
         self.data.clear()
 
     def write(self):
         for n in self.data:
-            n.setPinned(1)
+            n.setPinned(True)
             
     def clearskeleton(self):
         for n in self.data:
-            n.setPinned(0)
+            n.setPinned(False)
 
     def implied_pin(self, oldtracker):
         for n in oldtracker.get():
